@@ -25,7 +25,6 @@ import os, os.path
 
 import data #own data
 from myFunctions import * #Own functions
-#from myMP3 import * #Own functions to play an MP3
 
 #GUIs
 from Ui_StartWindow import *
@@ -381,6 +380,7 @@ def showGraph(self):
 #        print shift,  data.arrDataIndex-data.derivation,  Xscale
         
         end=data.arrDataIndex-shift-data.derivation
+        peak=0   
         for i in range(0,  end,  Xscale):
             k=i+shift
             
@@ -410,10 +410,10 @@ def showGraph(self):
 #                if(k>lastmove+1):k
 #            print i,  end,  Xscale
             if(peak>data.trigger or i>=end-Xscale):
+#            if(peak>data.trigger):
                 
-#                if(data.Mode==1): #quick mode for testing
-#                    playMP3() #make beep for testing
-                
+                        
+                        
 #                Show_passed_time("L 2")
 ##                    1=10 sec
 #                    if((i-lastmove)>30*Xscale): color="#009100" #green
@@ -431,13 +431,23 @@ def showGraph(self):
 #                        print x0,  "<=>",  x1,  t,  Xscale
                     if(t>30): color="#009100" #green
                     elif(t>15): color="#005000" #dark green
-                    else: color="#6D0000" #dark red                         
+                    else: color="#6D0000" #dark red       
+                    print "draw rect with color",  color                  
                     paint.setBrush(QtGui.QColor(color))
                     paint.setPen(QtGui.QColor(color))
                     paint.drawRect(x0, data.Ysize-11, x1-x0, 10)                     
                     paint.setPen(QtGui.QColor("yellow"))
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                 lastmove=i
+                
+                
+        
+        if(peak>data.trigger): #if last value is over peak
+            if(data.Mode==1 and (end-data.derivation)>data.last_beep): #quick mode for testing but only once pr move
+                if(data.demo==0): #make beep for testing movement
+                    b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
+                    b.close()
+                    data.last_beep=end
 
         Show_passed_time("showGraph End")
 
