@@ -36,9 +36,10 @@ def StartLogfile(interval):
     
     #open file, write header
     data.StartTime=time.localtime()
+    data.StartTimeSec=time.mktime(data.StartTime)
     t=strftime("%Y-%m-%d_%H-%M-%S", data.StartTime)
-    data.logfilename=data.logfolder+"SleepAnalyser_"+t+".csv"
-    data.logfile = open(data.logfilename, 'w')
+    data.logfilename="SleepAnalyser_"+t+".csv"
+    data.logfile = open(data.logfolder+data.logfilename, 'w')
     print "Created logfile "+data.logfilename
     t="Time, AccX, AccY, "
     d=strftime("%d-%m-%Y", data.StartTime)
@@ -46,7 +47,6 @@ def StartLogfile(interval):
             ", Sampling interval: " + str(interval)+" ms, sampling smoothing: " +str(data.sample_smoothing)+ \
             ", value_smoothing: " + str(data.sample_smoothing )+"\n") #Print file header
 
-    data.StartTimeSec=time.mktime(data.StartTime)
 
 
 
@@ -79,6 +79,7 @@ def StopLogfile():
 #  Load list of log files into array
 ###########################################################################
 def LoadFileList(dir):
+    Show_passed_time("LoadFileList Start")
     print "Load file list"
     output = os.popen("cd "+data.logfolder+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
     data.arrLogFiles=output.split("\n")
@@ -92,7 +93,8 @@ def LoadFileList(dir):
             
     data.arrLogFileIndex=(data.arrLogFileIndex+dir)  % len(data.arrLogFiles)
     data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
-    OpenLogFile()
+    Show_passed_time("LoadFileList End")
+
 
 
 
@@ -102,27 +104,27 @@ def LoadFileList(dir):
 #  Load old log file  to read and visualise it
 ###########################################################################
 def OpenLogFile():    
+    Show_passed_time("OpenLogFile Start")
     file = open(data.logfolder+data.logfilename, 'r')
     data.arrDataIndex=0
     print "Open logfile",  data.logfilename
     try:
         header=file.readline()
-        print "File data:",  header
+        print "Header:",  header
         for line in file:
             d=string.split(line,  ", ")
-            d[1]=int(d[1])
-            d[2]=int(d[2])
             data.arrData[0][data.arrDataIndex]=d[0] #time
-            data.arrData[1][data.arrDataIndex]=d[1] #X
-            data.arrData[2][data.arrDataIndex]=d[2] #Y
+            data.arrData[1][data.arrDataIndex]=int(d[1]) #X
+            data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
             data.arrDataIndex=data.arrDataIndex+1            
-            if(data.arrDataIndex==data.arrDataLen): 
-                print "Stopped, array is full, file is to big"
-                break
+#            if(data.arrDataIndex==data.arrDataLen): 
+#                print "Stopped, array is full, file is to big"
+#                break
     finally:
         file.close()
     
     print "Loaded",  str(data.arrDataIndex),  "lines"
+    Show_passed_time("OpenLogFile End")
     
     
     
@@ -167,9 +169,6 @@ def LoadConfig():
         config.set('main', 'Yscale', str(data.Yscale))      
         config.set('main', 'user', str(data.user))      
 
-    #faster sampling in demo mode
-    if(data.debug==1):
-        data.sampling=data.sampling/100
     
     #print usefull data
     print "SW version:", data.version
@@ -277,7 +276,7 @@ def GetSensorData():
 ###########################################################################
 def ProcessData():
     #DERIVATION (ABLEITUNG)
-    print "ProcessData"
+    Show_passed_time("ProcessData Start")
 #        print i,  data.arrData[0][i] ,  data.arrData[1][i],  data.arrData[2][i]  
     for i in range(0, data.arrDataIndex-data.derivation):
         data.arrData[3][i]=data.arrData[1][i+data.derivation] - data.arrData[1][i] #X  in 5 sec - X now
@@ -303,13 +302,24 @@ def ProcessData():
 #        print i,  data.arrData[0][i],  data.arrData[4][i],  data.arrData[5][i],  data.arrData[6][i],  x
 #
 
+    Show_passed_time("ProcessData End")
 
 
 
 
 
 
+###########################################################################
+# Function to measure used time in a function
+###########################################################################
+def Show_passed_time(text=""):
+#    global passed_time
+    if(data.debug==0): return
+    now=time.time()
+    t=1000*(now-data.passed_time)
+    print "+++++++++",  str(int(t)), "ms: ", text
 
+    data.passed_time = time.time()
 
 
 
